linchpin init
=============

Usage: ``linchpin init``

Initializes a linchpin project, which generates an example PinFile, and creates the necessary directory structure for topologies and layouts.

.. note:: If the PinFile/directories already exists in the current working directory it prompts user with yes/no option to override the existing file structure and PinFile.

**Options**

``--help``
    Print the help text for this command.

Examples
--------

+------------------------+---------------------------------------------------------+
| Usage                  | Action                                                  |
+========================+=========================================================+
| linchpin init          |  initialises the directory structure for up & destroy   |
+------------------------+---------------------------------------------------------+

.. seealso::
    * :doc:`linchpincli`
    * :doc:`linchpincli_linchpin_up`
    * :doc:`linchpincli_linchpin_destroy`
